Index: /issm/trunk-jpl/src/c/classes/Elements/Element.cpp
===================================================================
--- /issm/trunk-jpl/src/c/classes/Elements/Element.cpp	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/Elements/Element.cpp	(revision 21578)
@@ -1562,6 +1562,6 @@
 				name==EsaEmotionEnum || 
 				name==EsaDeltathicknessEnum || 
-				name==GiaIvinsWEnum || 
-				name==GiaIvinsdWdtEnum ||
+				name==GiaWEnum || 
+				name==GiadWdtEnum ||
 				name==SedimentHeadEnum ||
 				name==EplHeadEnum ||
Index: /issm/trunk-jpl/src/c/classes/Elements/Element.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/Elements/Element.h	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/Elements/Element.h	(revision 21578)
@@ -294,6 +294,6 @@
 		virtual void       ZeroLevelsetCoordinates(IssmDouble** pxyz_zero,IssmDouble* xyz_list,int levelsetenum)=0;
 
-		#ifdef _HAVE_GIAIVINS_
-		virtual void       GiaIvinsDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y)=0;
+		#ifdef _HAVE_GIA_
+		virtual void       GiaDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y)=0;
 		#endif
 		#ifdef _HAVE_ESA_
Index: /issm/trunk-jpl/src/c/classes/Elements/Penta.cpp
===================================================================
--- /issm/trunk-jpl/src/c/classes/Elements/Penta.cpp	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/Elements/Penta.cpp	(revision 21578)
@@ -3536,7 +3536,7 @@
 /*}}}*/
 
-#ifdef _HAVE_GIAIVINS_
-void       Penta::GiaIvinsDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y){/*{{{*/
-	_error_("GIAIVINS deflection not implemented yet!");
+#ifdef _HAVE_GIA_
+void       Penta::GiaDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y){/*{{{*/
+	_error_("GIA deflection not implemented yet!");
 }
 /*}}}*/
Index: /issm/trunk-jpl/src/c/classes/Elements/Penta.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/Elements/Penta.h	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/Elements/Penta.h	(revision 21578)
@@ -182,6 +182,6 @@
 		#endif
 
-		#ifdef _HAVE_GIAIVINS_
-		void           GiaIvinsDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y);
+		#ifdef _HAVE_GIA_
+		void           GiaDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y);
 		#endif
 		#ifdef _HAVE_ESA_
Index: /issm/trunk-jpl/src/c/classes/Elements/Seg.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/Elements/Seg.h	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/Elements/Seg.h	(revision 21578)
@@ -165,6 +165,6 @@
 		IssmDouble     GetAreaSpherical(void){_error_("not implemented yet!");};
 
-#ifdef _HAVE_GIAIVINS_
-		void        GiaIvinsDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y){_error_("not implemented yet");};
+#ifdef _HAVE_GIA_
+		void        GiaDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y){_error_("not implemented yet");};
 #endif
 #ifdef _HAVE_ESA_
Index: /issm/trunk-jpl/src/c/classes/Elements/Tetra.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/Elements/Tetra.h	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/Elements/Tetra.h	(revision 21578)
@@ -172,6 +172,6 @@
 		void        ZeroLevelsetCoordinates(IssmDouble** pxyz_zero,IssmDouble* xyz_list,int levelsetenum);
 
-#ifdef _HAVE_GIAIVINS_
-		void        GiaIvinsDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y){_error_("not implemented yet");};
+#ifdef _HAVE_GIA_
+		void        GiaDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y){_error_("not implemented yet");};
 #endif
 #ifdef _HAVE_ESA_
Index: /issm/trunk-jpl/src/c/classes/Elements/Tria.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/Elements/Tria.h	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/Elements/Tria.h	(revision 21578)
@@ -141,6 +141,6 @@
 		void        ZeroLevelsetCoordinates(IssmDouble** pxyz_zero,IssmDouble* xyz_list,int levelsetenum);
 
-		#ifdef _HAVE_GIAIVINS_
-		void   GiaIvinsDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y);
+		#ifdef _HAVE_GIA_
+		void   GiaDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x,IssmDouble* y);
 		#endif
 		#ifdef _HAVE_ESA_
Index: /issm/trunk-jpl/src/c/classes/FemModel.cpp
===================================================================
--- /issm/trunk-jpl/src/c/classes/FemModel.cpp	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/FemModel.cpp	(revision 21578)
@@ -628,5 +628,5 @@
 			break;
 
-		case GiaIvinsSolutionEnum:
+		case GiaSolutionEnum:
 			analyses_temp[numanalyses++]=GiaIvinsAnalysisEnum;
 			break;
@@ -649,5 +649,5 @@
 
 		case TransientSolutionEnum:{
-			bool isSIA,isFS,isthermal,isenthalpy,ismasstransport,isgroundingline,isstressbalance,ismovingfront,ishydrology,isdamage,issmb,isslr,isesa,isgiaivins;
+			bool isSIA,isFS,isthermal,isenthalpy,ismasstransport,isgroundingline,isstressbalance,ismovingfront,ishydrology,isdamage,issmb,isslr,isesa,isgia;
 			iomodel->FindConstant(&isSIA,"md.flowequation.isSIA");
 			iomodel->FindConstant(&isFS,"md.flowequation.isFS");
@@ -663,5 +663,5 @@
 			iomodel->FindConstant(&isslr,"md.transient.isslr");
 			iomodel->FindConstant(&isesa,"md.transient.isesa");
-			iomodel->FindConstant(&isgiaivins,"md.transient.isgiaivins");
+			iomodel->FindConstant(&isgia,"md.transient.isgia");
 			if(isstressbalance){
 				int  fe_FS;
@@ -710,5 +710,5 @@
 				analyses_temp[numanalyses++]=EsaAnalysisEnum;
 			}
-			if(isgiaivins){
+			if(isgia){
 				analyses_temp[numanalyses++]=GiaIvinsAnalysisEnum;
 			}
@@ -2317,5 +2317,5 @@
 /*}}}*/
 #endif
-#ifdef _HAVE_GIAIVINS_
+#ifdef _HAVE_GIA_
 void FemModel::Deflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt, IssmDouble* x, IssmDouble* y){ /*{{{*/
 
@@ -2323,5 +2323,5 @@
 	for(int i=0;i<elements->Size();i++){
 		Element* element=xDynamicCast<Element*>(elements->GetObjectByOffset(i));
-		element->GiaIvinsDeflection(wg,dwgdt, x,y);
+		element->GiaDeflection(wg,dwgdt, x,y);
 	}
 }
Index: /issm/trunk-jpl/src/c/classes/FemModel.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/FemModel.h	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/FemModel.h	(revision 21578)
@@ -117,5 +117,5 @@
 		void ThicknessAbsGradientx( IssmDouble* pJ);
 		void ThicknessPositivex(IssmDouble* pJ);
-		#ifdef _HAVE_GIAIVINS_
+		#ifdef _HAVE_GIA_
 		void Deflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt, IssmDouble* x, IssmDouble* y);
 		#endif
Index: /issm/trunk-jpl/src/c/classes/GiaDeflectionCoreArgs.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/GiaDeflectionCoreArgs.h	(revision 21578)
+++ /issm/trunk-jpl/src/c/classes/GiaDeflectionCoreArgs.h	(revision 21578)
@@ -0,0 +1,40 @@
+/*!\file:  GiaDeflectionCoreArgs.h
+ * \brief place holder for arguments to the GiaDeflectionCoreArgs routine
+ */ 
+
+#ifndef _GIADEFLECTIONCOREARGS_H_
+#define _GIADEFLECTIONCOREARGS_H_
+
+struct GiaDeflectionCoreArgs{
+
+	/*inputs: */
+	IssmDouble currenttime; 
+	IssmDouble* hes; //loading history (in ice thickness)
+	int numtimes; //loading history length
+	IssmDouble ri; //radial distance from center of disk to vertex  i
+	IssmDouble re; //radius of disk
+	IssmDouble* times; //loading history times
+
+	/*gia material parameters: */
+	IssmDouble lithosphere_density;
+	IssmDouble lithosphere_shear_modulus;
+	IssmDouble lithosphere_thickness;
+	IssmDouble mantle_density;
+	IssmDouble mantle_shear_modulus;
+	IssmDouble mantle_viscosity;
+
+	/*gia solution parameters: */
+	int iedge;
+
+	/*ice properties: */
+	IssmDouble rho_ice;
+
+	/*constants: */
+	IssmDouble yts;
+
+	/*debug info: */
+	int        idisk; //id of the element we are running the gia code in.
+
+};
+
+#endif
Index: sm/trunk-jpl/src/c/classes/GiaIvinsDeflectionCoreArgs.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/GiaIvinsDeflectionCoreArgs.h	(revision 21577)
+++ 	(revision )
@@ -1,40 +1,0 @@
-/*!\file:  GiaIvinsDeflectionCoreArgs.h
- * \brief place holder for arguments to the GiaIvinsDeflectionCoreArgs routine
- */ 
-
-#ifndef _GIAIVINSDEFLECTIONCOREARGS_H_
-#define _GIAIVINSDEFLECTIONCOREARGS_H_
-
-struct GiaIvinsDeflectionCoreArgs{
-
-	/*inputs: */
-	IssmDouble currenttime; 
-	IssmDouble* hes; //loading history (in ice thickness)
-	int numtimes; //loading history length
-	IssmDouble ri; //radial distance from center of disk to vertex  i
-	IssmDouble re; //radius of disk
-	IssmDouble* times; //loading history times
-
-	/*gia material parameters: */
-	IssmDouble lithosphere_density;
-	IssmDouble lithosphere_shear_modulus;
-	IssmDouble lithosphere_thickness;
-	IssmDouble mantle_density;
-	IssmDouble mantle_shear_modulus;
-	IssmDouble mantle_viscosity;
-
-	/*gia solution parameters: */
-	int iedge;
-
-	/*ice properties: */
-	IssmDouble rho_ice;
-
-	/*constants: */
-	IssmDouble yts;
-
-	/*debug info: */
-	int        idisk; //id of the element we are running the gia code in.
-
-};
-
-#endif
Index: /issm/trunk-jpl/src/c/classes/classes.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/classes.h	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/classes.h	(revision 21578)
@@ -126,5 +126,5 @@
 #include "./Update.h"
 #include "./FemModel.h"
-#include "./GiaIvinsDeflectionCoreArgs.h"
+#include "./GiaDeflectionCoreArgs.h"
 #include "./RiftStruct.h"
 

Index: /issm/trunk-jpl/src/c/classes/Elements/Tria.cpp
===================================================================
--- /issm/trunk-jpl/src/c/classes/Elements/Tria.cpp	(revision 21577)
+++ /issm/trunk-jpl/src/c/classes/Elements/Tria.cpp	(revision 21578)
@@ -15,6 +15,6 @@
 #include "../classes.h"
 #include "../../shared/shared.h"
-#ifdef _HAVE_GIAIVINS_
-#include "../../modules/GiaIvinsDeflectionCorex/GiaIvinsDeflectionCorex.h"
+#ifdef _HAVE_GIA_
+#include "../../modules/GiaDeflectionCorex/GiaDeflectionCorex.h"
 #endif
 /*}}}*/
@@ -3453,6 +3453,6 @@
 /*}}}*/
 
-#ifdef _HAVE_GIAIVINS_
-void       Tria::GiaIvinsDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x, IssmDouble* y){/*{{{*/
+#ifdef _HAVE_GIA_
+void       Tria::GiaDeflection(Vector<IssmDouble>* wg,Vector<IssmDouble>* dwgdt,IssmDouble* x, IssmDouble* y){/*{{{*/
 
 	int i;
@@ -3492,6 +3492,6 @@
 	IssmDouble  dwidt;
 
-	/*arguments to GiaIvinsDeflectionCorex: */
-	GiaIvinsDeflectionCoreArgs arguments;
+	/*arguments to GiaDeflectionCorex: */
+	GiaDeflectionCoreArgs arguments;
 
 	/*how many dofs are we working with here? */
@@ -3500,5 +3500,5 @@
 
 	/*recover gia solution parameters: */
-	this->parameters->FindParam(&cross_section_shape,GiaIvinsCrossSectionShapeEnum);
+	this->parameters->FindParam(&cross_section_shape,GiaCrossSectionShapeEnum);
 
 	/*what time is it? :*/
@@ -3518,10 +3518,10 @@
 
 	/*recover mantle viscosity: */
-	mantle_viscosity_input=inputs->GetInput(GiaIvinsMantleViscosityEnum);
+	mantle_viscosity_input=inputs->GetInput(GiaMantleViscosityEnum);
 	if (!mantle_viscosity_input)_error_("mantle viscosity input needed to compute gia deflection!");
 	mantle_viscosity_input->GetInputAverage(&mantle_viscosity);
 
 	/*recover lithosphere thickness: */
-	lithosphere_thickness_input=inputs->GetInput(GiaIvinsLithosphereThicknessEnum);
+	lithosphere_thickness_input=inputs->GetInput(GiaLithosphereThicknessEnum);
 	if (!lithosphere_thickness_input)_error_("lithosphere thickness input needed to compute gia deflection!");
 	lithosphere_thickness_input->GetInputAverage(&lithosphere_thickness);
@@ -3538,5 +3538,5 @@
 	y0=(xyz_list[0][1]+xyz_list[1][1]+xyz_list[2][1])/3.0;
 
-	/*start loading GiaIvinsDeflectionCore arguments: */
+	/*start loading GiaDeflectionCore arguments: */
 	arguments.re=re;
 	arguments.hes=hes;
@@ -3564,5 +3564,5 @@
 
 		/*for this Tria, compute contribution to rebound at vertex i: */
-		GiaIvinsDeflectionCorex(&wi,&dwidt,&arguments);
+		GiaDeflectionCorex(&wi,&dwidt,&arguments);
 
 		/*plug value into solution vector: */